pub enum ObjectHeader {
Regular {
obj_type: ObjectType,
uncompressed_data_size: usize,
raw_data: Vec<u8>,
},
OfsDelta {
uncompressed_data_size: usize,
base_offset: i64,
raw_data: Vec<u8>,
},
RefDelta {
uncompressed_data_size: usize,
base_ref: [u8; 20],
raw_data: Vec<u8>,
},
}Variants
Implementations
Sourceimpl ObjectHeader
impl ObjectHeader
pub fn obj_type(&self) -> ObjectType
pub fn uncompressed_data_size(&self) -> usize
pub fn raw_data(&self) -> &[u8] ⓘ
Sourcepub fn parse(input: &[u8]) -> IResult<&[u8], Self>
pub fn parse(input: &[u8]) -> IResult<&[u8], Self>
Every byte of the header has its Most Significant Bit used as a continuation bit: 0 -> this is the last byte 1 -> there is the next byte
After the continuation bit in the first byte there are 3 bits for the type. Type 5 is reserved for future expansion. Type 0 is invalid.